@@ -422,17 +422,11 @@ MainWindow *Application::processWindowArgs(bool &createdNewMainWindow)
         if (m_parser->isSet(QStringLiteral("fullscreen"))) {
             window->viewFullScreen(true);
         }
-
-        // override default tabbbar visibility
-        // FIXME: remove those magic number
-        // see ViewContainer::NavigationVisibility
         if (m_parser->isSet(QStringLiteral("show-tabbar"))) {
-            // always show
-            window->viewManager()->setNavigationVisibility(0);
+            window->viewManager()->setNavigationVisibility(ViewManager::AlwaysShowNavigation);
         }
-        if (m_parser->isSet(QStringLiteral("hide-tabbar"))) {
-            // never show
-            window->viewManager()->setNavigationVisibility(2);
+        else if (m_parser->isSet(QStringLiteral("hide-tabbar"))) {
+            window->viewManager()->setNavigationVisibility(ViewManager::AlwaysHideNavigation);
         }
     }
     return window;
