@@ -114,6 +114,9 @@ public:
          * resizing the application window.
          */
         ShowTerminalSizeHint,
+        /** (bool) If the background color should change to indicate if the window is active
+         */
+        DimWhenInactive,
         /** (QFont) The font to use in terminal displays using this profile. */
         Font,
         /** (QString) The name of the color scheme to use in terminal
@@ -288,7 +291,9 @@ public:
         */
         AlternateScrolling,
         /** (int) Keyboard modifiers to show URL hints */
-        UrlHintsModifiers
+        UrlHintsModifiers,
+        /** (bool) Reverse the order of URL hints */
+        ReverseUrlHints
     };
 
     /**
@@ -437,6 +442,12 @@ public:
         return property<bool>(Profile::ShowTerminalSizeHint);
     }
 
+    /** Convenience method for property<bool>(Profile::DimWhenInactive) */
+    bool dimWhenInactive() const
+    {
+        return property<bool>(Profile::DimWhenInactive);
+    }
+
     /** Convenience method for property<QFont>(Profile::Font) */
     QFont font() const
     {
