@@ -35,8 +35,10 @@ using Konsole::ProfileList;
 
 ProfileList::ProfileList(bool addShortcuts , QObject* parent)
     : QObject(parent)
+    , _group(nullptr)
     , _addShortcuts(addShortcuts)
     , _emptyListAction(nullptr)
+    , _registeredWidgets(QSet<QWidget *>())
 {
     // construct the list of favorite profiles
     _group = new QActionGroup(this);
@@ -68,14 +70,16 @@ void ProfileList::updateEmptyAction()
     // show this action only when it is the only action in the group
     const bool showEmptyAction = (_group->actions().count() == 1);
 
-    if (showEmptyAction != _emptyListAction->isVisible())
+    if (showEmptyAction != _emptyListAction->isVisible()) {
         _emptyListAction->setVisible(showEmptyAction);
+    }
 }
 QAction* ProfileList::actionForProfile(Profile::Ptr profile) const
 {
     foreach(QAction* action, _group->actions()) {
-        if (action->data().value<Profile::Ptr>() == profile)
+        if (action->data().value<Profile::Ptr>() == profile) {
             return action;
+        }
     }
     return nullptr; // not found
 }
@@ -83,8 +87,9 @@ QAction* ProfileList::actionForProfile(Profile::Ptr profile) const
 void ProfileList::profileChanged(Profile::Ptr profile)
 {
     QAction* action = actionForProfile(profile);
-    if (action != nullptr)
+    if (action != nullptr) {
         updateAction(action, profile);
+    }
 }
 
 void ProfileList::updateAction(QAction* action , Profile::Ptr profile)
@@ -97,8 +102,9 @@ void ProfileList::updateAction(QAction* action , Profile::Ptr profile)
 }
 void ProfileList::shortcutChanged(Profile::Ptr profile, const QKeySequence& sequence)
 {
-    if (!_addShortcuts)
+    if (!_addShortcuts) {
         return;
+    }
 
     QAction* action = actionForProfile(profile);
 
@@ -122,38 +128,51 @@ void ProfileList::syncWidgetActions(QWidget* widget, bool sync)
 
     widget->addActions(_group->actions());
 }
-void ProfileList::favoriteChanged(Profile::Ptr profile, bool isFavorite)
+
+void ProfileList::addShortcutAction(Profile::Ptr profile)
 {
     ProfileManager* manager = ProfileManager::instance();
 
-    if (isFavorite) {
-        auto action = new QAction(_group);
-        action->setData(QVariant::fromValue(profile));
+    auto action = new QAction(_group);
+    action->setData(QVariant::fromValue(profile));
 
-        if (_addShortcuts) {
-            action->setShortcut(manager->shortcut(profile));
-        }
-
-        updateAction(action, profile);
-
-        foreach(QWidget * widget, _registeredWidgets) {
-            widget->addAction(action);
-        }
-        emit actionsChanged(_group->actions());
-    } else {
-        QAction* action = actionForProfile(profile);
-
-        if (action != nullptr) {
-            _group->removeAction(action);
-            foreach(QWidget * widget, _registeredWidgets) {
-                widget->removeAction(action);
-            }
-            emit actionsChanged(_group->actions());
-        }
+    if (_addShortcuts) {
+        action->setShortcut(manager->shortcut(profile));
     }
 
+    updateAction(action, profile);
+
+    foreach(QWidget * widget, _registeredWidgets) {
+        widget->addAction(action);
+    }
+    emit actionsChanged(_group->actions());
+
     updateEmptyAction();
 }
+
+void ProfileList::removeShortcutAction(Profile::Ptr profile)
+{
+    QAction* action = actionForProfile(profile);
+
+    if (action != nullptr) {
+        _group->removeAction(action);
+        foreach(QWidget * widget, _registeredWidgets) {
+            widget->removeAction(action);
+        }
+        emit actionsChanged(_group->actions());
+    }
+    updateEmptyAction();
+}
+
+void ProfileList::favoriteChanged(Profile::Ptr profile, bool isFavorite)
+{
+    if (isFavorite) {
+        addShortcutAction(profile);
+    } else {
+        removeShortcutAction(profile);
+    }
+}
+
 void ProfileList::triggered(QAction* action)
 {
     emit profileSelected(action->data().value<Profile::Ptr>());
