@@ -284,6 +284,10 @@ private:
         QString profilePath;
     };
     QMap<QKeySequence, ShortcutData> _shortcuts; // shortcut keys -> profile path
+
+    // finds out if it's a internal profile or an external one,
+    // fixing the path to point to the correct location for the profile.
+    QString normalizePath(const QString& path) const;
 };
 
 /**
