@@ -21,10 +21,10 @@
 #define DBUSTEST_H
 
 #include <QTest>
-#include <QtDBus/QtDBus>
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusReply>
-#include <QtCore/QTextCodec>
+#include <QDBusInterface>
+#include <QDBusConnectionInterface>
+#include <QDBusReply>
+#include <QTextCodec>
 
 #include <unistd.h>
 
@@ -36,13 +36,13 @@ class DBusTest : public QObject
     Q_OBJECT
 public:
 
-private slots:
+private Q_SLOTS:
     void initTestCase();
     void cleanupTestCase();
     void testSessions();
 
 // protected slots are not treated as test cases
-protected slots:
+protected Q_SLOTS:
 
 private:
     QString _interfaceName;
